@@ -780,7 +780,11 @@ class WitterUI():
         reply_all.set_title('Reply All')
         reply_all.connect("clicked", self.controller.replyAll)
         hbox0.pack_start(reply_all, expand=True)
-
+        retweet = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        retweet.set_title('Retweet')
+        retweet.connect("clicked", self.controller.reTweet)
+        hbox0.pack_start(retweet, expand=True)
         #direct message
         dm = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                   hildon.BUTTON_ARRANGEMENT_VERTICAL)
